==> huaweicloudsdkdcs-3.1.66-py2.py3-none-any.whl: huaweicloudsdkdcs/v2/model/list_acl_accounts_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAclAccountsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'accounts': 'list[AclAccountResp]'
    }

    attribute_map = {
        'accounts': 'accounts'
    }

    def __init__(self, accounts=None):
        """ListAclAccountsResponse

        The model defined in huaweicloud sdk

        :param accounts: ACL账号列表
        :type accounts: list[:class:`huaweicloudsdkdcs.v2.AclAccountResp`]
        """
        
        super(ListAclAccountsResponse, self).__init__()

        self._accounts = None
        self.discriminator = None

        if accounts is not None:
            self.accounts = accounts

    @property
    def accounts(self):
        """Gets the accounts of this ListAclAccountsResponse.

        ACL账号列表

        :return: The accounts of this ListAclAccountsResponse.
        :rtype: list[:class:`huaweicloudsdkdcs.v2.AclAccountResp`]
        """
        return self._accounts

    @accounts.setter
    def accounts(self, accounts):
        """Sets the accounts of this ListAclAccountsResponse.

        ACL账号列表

        :param accounts: The accounts of this ListAclAccountsResponse.
        :type accounts: list[:class:`huaweicloudsdkdcs.v2.AclAccountResp`]
        """
        self._accounts = accounts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAclAccountsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdcs-3.1.157-py2.py3-none-any.whl: huaweicloudsdkdcs/v2/model/list_acl_accounts_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAclAccountsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'accounts': 'list[AclAccountResp]'
    }

    attribute_map = {
        'accounts': 'accounts'
    }

    def __init__(self, accounts=None):
        r"""ListAclAccountsResponse

        The model defined in huaweicloud sdk

        :param accounts: ACL账号列表
        :type accounts: list[:class:`huaweicloudsdkdcs.v2.AclAccountResp`]
        """
        
        super(ListAclAccountsResponse, self).__init__()

        self._accounts = None
        self.discriminator = None

        if accounts is not None:
            self.accounts = accounts

    @property
    def accounts(self):
        r"""Gets the accounts of this ListAclAccountsResponse.

        ACL账号列表

        :return: The accounts of this ListAclAccountsResponse.
        :rtype: list[:class:`huaweicloudsdkdcs.v2.AclAccountResp`]
        """
        return self._accounts

    @accounts.setter
    def accounts(self, accounts):
        r"""Sets the accounts of this ListAclAccountsResponse.

        ACL账号列表

        :param accounts: The accounts of this ListAclAccountsResponse.
        :type accounts: list[:class:`huaweicloudsdkdcs.v2.AclAccountResp`]
        """
        self._accounts = accounts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAclAccountsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
